<template>
  <div id="metroChart" ref="chart" style="height: 100%"></div>
</template>

<script>
import echarts from "echarts";

let myChart;
export default {
  props: {
    lines: {
      type: Array,
      default() {
        return []
      }
    },
    status: {
      type: Object,
      default() {
        return {}
      }
    }
  },
  data() {
    return {
      jsonData: {},
    }
  },
  computed: {
    lineList() {
      // console.log('line', this.lines)
      return this.lines.map(v => v + '号线');
    }
  },
  watch: {
    lines() {
      // console.log('line', this.lines, '=============');
      this.updateMap();
    },
    status() {
      this.updateMap();
    }
  },
  methods: {
    async getJson() {
      const dynamicPath = `mapJson/subway/suzhou1.json`;
      try {
        const response = await fetch(dynamicPath);
        if (!response.ok) {
          throw new Error(`HTTP error! status: ${response.status}`);
        }
        const data = await response.json();
        // console.log("data", data, "=============");
        // this.defaultData = data.l;
        return data;
      } catch (error) {
        console.error("加载 JSON 出错:", error);
      }
    },

    async getSubwayJson() {
      const { l } = this.jsonData;
      let stationList = this.lineList;
      const subwayList = l.filter((item) => {
        return stationList.includes(item.ln);
      });
      // 站点状态
      let statusList = this.status;

      const position = {
        0: "top",
        1: "topRight",
        2: "right",
        3: "bottomRight",
        4: "bottom",
        5: "bottomLeft",
        6: "left",
        7: "topLeft",
      };
      const list = {
        xPeak: {
          min: 0,
          max: 0,
        },
        yPeak: {
          min: 0,
          max: 0,
        },
        names: [],
        x: [],
        y: [],
        nodes: [],
        lines: [],
      };
      for (let i = 0; i < subwayList.length; i++) {
        const { cl, st, ln, x } = subwayList[i];
        let lineNum = x;
        for (let k = 0; k < st.length; k++) {
          const { n, p, lg } = st[k];
          const point = p.split(" ");
          const x = Number(point[0]);
          const y = Number(point[1]);
          list.x.push(x);
          list.y.push(y);
          if (!list.names.includes(n)) {
            list.names.push(n);
            const names = n.split("");
            let p = "";
            let offset = [0, 0];
            if (position[lg] === "topLeft") {
              p = "left";
              offset = [0, -8];
            } else if (position[lg] === "topRight") {
              p = "right";
              offset = [0, -8];
            } else if (position[lg] === "bottomLeft") {
              p = "left";
              offset = [0, 12];
            } else if (position[lg] === "bottomRight") {
              p = "right";
              offset = [0, 12];
            } else {
              p = position[lg];
            }
            let stations = statusList[lineNum].filter(v => v.stationName8 == n);

            let status = stations.length ? stations[0].note == 1 : false;
            list.nodes.push({
              category: i,
              name: n,
              x,
              status,
              y,
              color: "#" + cl,
              p,
              offset,
            });
          }
          if (k !== st.length - 1) {
            list.lines.push({
              source: n,
              target: st[k + 1].n,
              lineStyle: {
                normal: {
                  color: "#" + cl,
                  width: 3,
                },
              },
            });
          }
        }
      }
      list.xPeak = {
        min: Math.min(...list.x),
        max: Math.max(...list.x),
      };
      list.yPeak = {
        min: Math.min(...list.y),
        max: Math.max(...list.y),
      };
      return list;
    },
    async updateMap() {
      let metroData = await this.getSubwayJson();
      const { l } = this.jsonData;
      
      const option = {
        xAxis: {
          show: false,
          type: "value",
          min: metroData.xPeak.min,
          max: metroData.xPeak.max,
          position: "top",
        },
        yAxis: {
          show: false,
          type: "value",
          min: metroData.yPeak.min,
          max: metroData.yPeak.max,
        },
        legend: [
          {
            data: this.lineList,
            textStyle: {
              color: '#fff'
            },
          }
        ],
        series: [
          {
            type: "graph",
            layout: "none",
            roam: true,
            labelLayout: {
              hideOverlap: true,
            },
            categories: this.lineList.map(v=>({name: v, itemStyle: {color: '#' + l.filter(item => item.ln == v)[0].cl}})),
            data: metroData.nodes.map((node) => ({
              name: node.name,
              symbol: "circle",
              symbolSize: 6,
              category: node.category,
              x: node.x,
              y: node.y,
              itemStyle: {
                color: node.status ? '#0f0' : "#f00",
                // borderColor: node.color,
              },
              label: {
                show: true,
                position: node.p,
                color: '#fff',
                offset: node.offset,
              },
            })),
            links: metroData.lines,
          },
        ],
      };
      myChart.setOption(option);

    },
  },

  async mounted() {
    this.jsonData = await this.getJson();
    myChart = echarts.init(this.$refs.chart);
    this.updateMap();

    myChart.on('legendselectchanged', (param) => {
      this.$emit('legend-change', param.selected);
    });
  },
};
</script>
